ControlMessage

Enum ControlMessage 

pub enum ControlMessage {
Show 42 variants Resize { cols: u16, rows: u16, }, Input { data: Vec<u8>, }, LoadPlugin { path: String, }, Ping { timestamp: u64, }, Disconnect { client_id: u64, }, SessionCreate { name: String, }, SessionDelete { id: String, }, SessionList, SessionAttach { id: String, }, SessionDetach { id: String, }, SessionRename { id: String, new_name: String, }, TabCreate { title: Option<String>, }, TabClose { tab_id: u64, }, TabSwitch { tab_id: u64, }, TabRename { tab_id: u64, new_title: String, }, TabList, PaneSplit { pane_id: u64, direction: SplitDirection, }, PaneClose { pane_id: u64, }, PaneFocus { pane_id: u64, }, PaneResize { pane_id: u64, width: u16, height: u16, }, PaneFocusNext, PaneFocusPrev, TabNext, TabPrev, MouseClick { col: u16, row: u16, button: u8, }, CommandSelected { id: String, }, PluginListRequest, PluginEnable { name: String, }, PluginDisable { name: String, }, PluginReload { name: String, }, PluginMenuRequest { plugin_name: String, }, PluginMenuExecute { plugin_name: String, action: MenuActionType, }, PluginLog { plugin_name: String, level: LogLevel, message: String, }, PluginNotify { title: String, body: String, level: NotifyLevel, }, NavEnterHintMode { plugin_name: String, }, NavExitMode { plugin_name: String, }, NavRegisterFocusable { plugin_name: String, x: u16, y: u16, width: u16, height: u16, label: String, action: NavFocusableAction, }, NavUnregisterFocusable { plugin_name: String, focusable_id: u64, }, ZonesRequest, CopyLastOutput, SelectZone { zone_id: u64, }, ExtractZoneText { zone_id: u64, },
}

Variants



Resize

Fields

cols: u16
rows: u16


Input

Fields

data: Vec<u8>


LoadPlugin

Fields

path: String


Ping

Fields

timestamp: u64


Disconnect

Fields

client_id: u64


SessionCreate

Fields

name: String


SessionDelete

Fields



SessionList



SessionAttach

Fields



SessionDetach

Fields



SessionRename

Fields

new_name: String


TabCreate

Fields



TabClose

Fields

tab_id: u64


TabSwitch

Fields

tab_id: u64


TabRename

Fields

tab_id: u64
new_title: String


TabList



PaneSplit

Fields

pane_id: u64
direction: SplitDirection


PaneClose

Fields

pane_id: u64


PaneFocus

Fields

pane_id: u64


PaneResize

Fields

pane_id: u64
width: u16
height: u16


PaneFocusNext

Focus the next pane in the current tab (for navigation)



PaneFocusPrev

Focus the previous pane in the current tab (for navigation)



TabNext

Switch to the next tab



TabPrev

Switch to the previous tab



MouseClick

Send mouse click event to the terminal

Fields

col: u16
row: u16
button: u8


CommandSelected

Fields



PluginListRequest



PluginEnable

Fields

name: String


PluginDisable

Fields

name: String


PluginReload

Fields

name: String


PluginMenuRequest

Fields

plugin_name: String


PluginMenuExecute

Fields

plugin_name: String


PluginLog

Fields

plugin_name: String
level: LogLevel
message: String


PluginNotify

Fields

title: String
body: String


NavEnterHintMode

Fields

plugin_name: String


NavExitMode

Fields

plugin_name: String


NavRegisterFocusable

Fields

plugin_name: String
width: u16
height: u16
label: String


NavUnregisterFocusable

Fields

plugin_name: String
focusable_id: u64


ZonesRequest

Request semantic zones update from daemon



CopyLastOutput

Copy the output from the last completed command



SelectZone

Select a specific zone by ID

Fields

zone_id: u64


ExtractZoneText

Extract text from a zone

Fields

zone_id: u64