pub struct PaneInfo {
pub id: u64,
pub x: u16,
pub y: u16,
pub width: u16,
pub height: u16,
pub is_focused: bool,
}Fields
id: u64x: u16y: u16width: u16height: u16is_focused: boolTrait Implementations
Sourceimpl Archive for PaneInfo
impl Archive for PaneInfo
Sourcetype Archived = ArchivedPaneInfo
type Archived = ArchivedPaneInfo
The archived representation of this type. Read more
Sourcetype Resolver = PaneInfoResolver
type Resolver = PaneInfoResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.