pub struct TabInfo {
pub id: u64,
pub title: String,
pub session_id: Option<String>,
pub is_active: bool,
pub pane_count: u32,
}Fields
id: u64title: Stringsession_id: Option<String>is_active: boolpane_count: u32Trait Implementations
Sourceimpl Archive for TabInfo
impl Archive for TabInfo
Sourcetype Archived = ArchivedTabInfo
type Archived = ArchivedTabInfo
The archived representation of this type. Read more
Sourcetype Resolver = TabInfoResolver
type Resolver = TabInfoResolver
The resolver for this type. It must contain all the additional information from serializing
needed to make the archived type from the normal type.
Sourceimpl<__D: Fallible + ?Sized> Deserialize<TabInfo, __D> for Archived<TabInfo>where
u64: Archive,
Archived<u64>: Deserialize<u64, __D>,
String: Archive,
Archived<String>: Deserialize<String, __D>,
Option<String>: Archive,
Archived<Option<String>>: Deserialize<Option<String>, __D>,
bool: Archive,
Archived<bool>: Deserialize<bool, __D>,
u32: Archive,
Archived<u32>: Deserialize<u32, __D>,
impl<__D: Fallible + ?Sized> Deserialize<TabInfo, __D> for Archived<TabInfo>where
u64: Archive,
Archived<u64>: Deserialize<u64, __D>,
String: Archive,
Archived<String>: Deserialize<String, __D>,
Option<String>: Archive,
Archived<Option<String>>: Deserialize<Option<String>, __D>,
bool: Archive,
Archived<bool>: Deserialize<bool, __D>,
u32: Archive,
Archived<u32>: Deserialize<u32, __D>,