ZoneTracker

Struct ZoneTracker 

pub struct ZoneTracker { /* private fields */ }
Zone tracking state for managing semantic zones

This is not directly serialized for IPC, but used internally by the daemon to track zones and generate SemanticZone messages for the client.

Implementations

Source

impl ZoneTracker

pub fn new(max_blocks: usize) -> Self

Create a new zone tracker

pub fn mark_prompt_start(&mut self, line: u32, timestamp: u64)

Handle OSC 133;A - Prompt start

pub fn mark_command_start(&mut self, line: u32, timestamp: u64)

Handle OSC 133;B - Command/input start

pub fn mark_command_executed(&mut self, line: u32, timestamp: u64)

Handle OSC 133;C - Command executed, output begins

pub fn mark_command_finished( &mut self, line: u32, exit_code: i32, timestamp: u64, )

Handle OSC 133;D - Command finished

pub fn set_command_text(&mut self, command: String)

Set command text for the most recent input zone

pub fn zones(&self) -> &[SemanticZone]

Get all tracked zones

pub fn command_blocks(&self) -> &[CommandBlock]

Get all completed command blocks

pub fn current_block(&self) -> Option<&CommandBlock>

Get the current incomplete command block

pub fn find_block_at_line(&self, line: u32) -> Option<&CommandBlock>

Find the command block containing the given line

pub fn find_zone_at_line(&self, line: u32) -> Option<&SemanticZone>

Find the zone containing the given line

pub fn last_output_zone(&self) -> Option<&SemanticZone>

Get the last output zone for “copy last output” functionality

pub fn clear(&mut self)

Clear all zones (useful for reset operations)

pub fn adjust_for_scroll(&mut self, lines_scrolled: i32)

Update zone line numbers after scrolling

When the terminal scrolls, line numbers in scrollback increase. This method adjusts zone line numbers accordingly.