pub enum ControlMessage {
Show 42 variants
Resize {
cols: u16,
rows: u16,
},
Input {
data: Vec<u8>,
},
LoadPlugin {
path: String,
},
Ping {
timestamp: u64,
},
Disconnect {
client_id: u64,
},
SessionCreate {
name: String,
},
SessionDelete {
id: String,
},
SessionList,
SessionAttach {
id: String,
},
SessionDetach {
id: String,
},
SessionRename {
id: String,
new_name: String,
},
TabCreate {
title: Option<String>,
},
TabClose {
tab_id: u64,
},
TabSwitch {
tab_id: u64,
},
TabRename {
tab_id: u64,
new_title: String,
},
TabList,
PaneSplit {
pane_id: u64,
direction: SplitDirection,
},
PaneClose {
pane_id: u64,
},
PaneFocus {
pane_id: u64,
},
PaneResize {
pane_id: u64,
width: u16,
height: u16,
},
PaneFocusNext,
PaneFocusPrev,
TabNext,
TabPrev,
MouseClick {
col: u16,
row: u16,
button: u8,
},
CommandSelected {
id: String,
},
PluginListRequest,
PluginEnable {
name: String,
},
PluginDisable {
name: String,
},
PluginReload {
name: String,
},
PluginMenuRequest {
plugin_name: String,
},
PluginMenuExecute {
plugin_name: String,
action: MenuActionType,
},
PluginLog {
plugin_name: String,
level: LogLevel,
message: String,
},
PluginNotify {
title: String,
body: String,
level: NotifyLevel,
},
NavEnterHintMode {
plugin_name: String,
},
NavExitMode {
plugin_name: String,
},
NavRegisterFocusable {
plugin_name: String,
x: u16,
y: u16,
width: u16,
height: u16,
label: String,
action: NavFocusableAction,
},
NavUnregisterFocusable {
plugin_name: String,
focusable_id: u64,
},
ZonesRequest,
CopyLastOutput,
SelectZone {
zone_id: u64,
},
ExtractZoneText {
zone_id: u64,
},
}Variants
Resize
Input
LoadPlugin
Ping
Disconnect
SessionCreate
SessionDelete
SessionList
SessionAttach
SessionDetach
SessionRename
TabCreate
TabClose
TabSwitch
TabRename
TabList
PaneSplit
PaneClose
PaneFocus
PaneResize
PaneFocusNext
Focus the next pane in the current tab (for navigation)
PaneFocusPrev
Focus the previous pane in the current tab (for navigation)
TabNext
Switch to the next tab
TabPrev
Switch to the previous tab
MouseClick
Send mouse click event to the terminal
CommandSelected
PluginListRequest
PluginEnable
PluginDisable
PluginReload
PluginMenuRequest
PluginMenuExecute
PluginLog
PluginNotify
ZonesRequest
Request semantic zones update from daemon
CopyLastOutput
Copy the output from the last completed command
SelectZone
Select a specific zone by ID
ExtractZoneText
Extract text from a zone